Security Advisories (1)
Perl versions through 5.43.10 have a heap buffer overflow when compiling regular expressions with a repeated fixed string on 32-bit builds. Perl_study_chunk in regcomp_study.c checked the size of the joined substring buffer in characters rather than bytes. For a quantified fixed substring with a large minimum count, the byte length mincount * l could overflow SSize_t, producing an undersized SvGROW allocation; the subsequent copy writes past the end of the buffer. A caller that compiles an attacker-controlled regular expression on a 32-bit perl build triggers a heap buffer overflow at compile time.
No POD found for configpm.
Time to read the source?
Module Install Instructions
To install less, copy and paste the appropriate command in to your terminal.
cpanm less
perl -MCPAN -e shell
install less
For more information on module installation, please visit the detailed CPAN module installation guide.